@@ -1,7 +1,7 @@
 // Visualisation  of  3 levels reconciliation
 //  Case there are several gene trees
 
-use light_phylogeny::{ArenaTree,Options,Config,read_recphyloxml,recphyloxml_processing,
+use light_phylogeny::{ArenaTree,Options,Config,read_recphyloxml_multi,recphyloxml_processing,
 phyloxml_processing,reset_pos,map_transfer,get_gtransfer,summary,
 map_parasite_g2s,map_parasite_s2g,map_gene_host};
 use log::{info};
@@ -36,7 +36,8 @@ fn main() {
     // Creation du vecteur de structure ArenaTree pour les genes
     // ---------------------------------------------------------
     let mut gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-    read_recphyloxml(infile_gene_para,&mut tree_para_pipe,&mut gene_trees);
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
+    read_recphyloxml_multi(infile_gene_para, &mut tree_para_pipe, &mut gene_trees, &mut global_roots);
     let  nb_gntree =  gene_trees.len().clone();
     // let mut gene_trees_clone:std::vec::Vec<ArenaTree<String>> = Vec::new();
     // let mut i = 0;
@@ -60,7 +61,8 @@ fn main() {
     // Creation du vecteur de structure ArenaTree pour les genes
     // ---------------------------------------------------------
     let mut para_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-    read_recphyloxml(infile_para_host,&mut tree_host_pipe,&mut para_trees);
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
+    read_recphyloxml_multi(infile_para_host,&mut tree_host_pipe,&mut para_trees, &mut global_roots);
     let  nb_paratree =  para_trees.len().clone();
     assert_eq!(nb_paratree,1,"I want only one parasite tree");
     println!("Number of gene trees : {}",nb_paratree);
